@@ -1,7 +1,5 @@
 from abc import ABC, abstractmethod
 from time import time
-import base58
-from nacl.signing import VerifyKey
 
 
 class Transaction(ABC):
@@ -57,3 +55,16 @@ class Transaction(ABC):
     def to_json(self):
         pass
 
+    def _init_from_data(self, data):
+        self.version = data['version']
+        self.id = data.get('id')
+        self.sender = data.get('sender')
+        self.sender_key_type = data.get('senderKeyType', 'ed25519' if 'senderPublicKey' in data else None)
+        self.sender_public_key = data.get('senderPublicKey')
+        self.sponsor = data.get('sponsor')
+        self.sponsor_public_key = data.get('sponsorPublicKey')
+        self.sponsor_key_type = data.get('sponsorKeyType')
+        self.fee = data.get('fee')
+        self.timestamp = data.get('timestamp')
+        self.proofs = data.get('proofs', [])
+        self.height = data.get('height')
