@@ -1,5 +1,6 @@
 import base58
 from lto import crypto
+from lto.binary import Binary
 from lto.transaction import Transaction
 import struct
 
@@ -10,20 +11,15 @@ class Anchor(Transaction):
     VAR_FEE = 10000000
     DEFAULT_VERSION = 3
 
-    def __init__(self, *anchors):
+    def __init__(self, *anchors: bytes):
         super().__init__()
 
-        self.anchors = anchors
+        self.anchors = [Binary(anchor) for anchor in anchors]
         self.tx_fee = self.BASE_FEE + len(anchors) * self.VAR_FEE
         self.version = self.DEFAULT_VERSION
 
     def __anchors_to_binary(self):
-        binary = b''
-        for anchor in self.anchors:
-            binary += struct.pack(">H", len(crypto.str2bytes(anchor)))
-            binary += crypto.str2bytes(anchor)
-
-        return binary
+        return b''.join(struct.pack(">H", len(anchor)) + anchor for anchor in self.anchors)
 
     def __to_binary_v1(self):
         return (self.TYPE.to_bytes(1, 'big') +
@@ -63,7 +59,7 @@ class Anchor(Transaction):
                 "senderPublicKey": self.sender_public_key,
                 "fee": self.tx_fee,
                 "timestamp": self.timestamp,
-                "anchors": list(map(lambda anchor: base58.b58encode(crypto.str2bytes(anchor)), self.anchors)),
+                "anchors": [anchor.base58() for anchor in self.anchors],
                 "sponsor": self.sponsor,
                 "sponsorKeyType": self.sponsor_key_type,
                 "sponsorPublicKey": self.sponsor_public_key,
@@ -73,22 +69,7 @@ class Anchor(Transaction):
 
     @staticmethod
     def from_data(data):
-        tx = Anchor("")
-        tx.id = data['id'] if 'id' in data else ''
-        tx.type = data['type']
-        tx.version = data['version']
-        tx.sender = data['sender'] if 'sender' in data else ''
-        tx.sender_key_type = data['senderKeyType'] if 'senderKeyType' in data else 'ed25519'
-        tx.sender_public_key = data['senderPublicKey']
-        tx.fee = data['fee']
-        tx.timestamp = data['timestamp']
-        tx.anchors = data['anchors']
-        tx.proofs = data['proofs'] if 'proofs' in data else []
-        tx.height = data['height'] if 'height' in data else ''
-
-        if "sponsor_public_key" in data:
-            tx.sponsor = data['sponsor']
-            tx.sponsor_public_key = data['sponsorPublicKey']
-            tx.sponsor_key_type = data['sponsorKeyType']
+        tx = Anchor(*map(lambda anchor: Binary.frombase58(anchor), data.get('anchors', [])))
+        tx._init_from_data(data)
 
         return tx
