@@ -2,6 +2,7 @@ import base58
 from lto import crypto
 import struct
 
+from lto.binary import Binary
 from lto.transaction import Transaction
 
 
@@ -11,10 +12,10 @@ class MassTransfer(Transaction):
     TYPE = 11
     DEFAULT_VERSION = 3
 
-    def __init__(self, transfers, attachment=''):
+    def __init__(self, transfers: list, attachment=''):
         super().__init__()
         self.transfers = transfers
-        self.attachment = attachment
+        self.attachment = Binary(attachment, 'utf-8') if type(attachment) == str else Binary(attachment)
         self.transfers_data = ''
         self.tx_fee = self.BASE_FEE + (len(self.transfers) * self.VAR_FEE)
         self.version = self.DEFAULT_VERSION
@@ -39,7 +40,7 @@ class MassTransfer(Transaction):
                 struct.pack(">Q", self.timestamp) +
                 struct.pack(">Q", self.tx_fee) +
                 struct.pack(">H", len(self.attachment)) +
-                crypto.str2bytes(self.attachment))
+                self.attachment)
 
     def __to_binary_v3(self):
         return (self.TYPE.to_bytes(1, 'big') +
@@ -52,7 +53,7 @@ class MassTransfer(Transaction):
                 struct.pack(">H", len(self.transfers)) +
                 self.__transfers_to_binary() +
                 struct.pack(">H", len(self.attachment)) +
-                crypto.str2bytes(self.attachment))
+                self.attachment)
 
     def to_binary(self):
         if self.version == 1:
@@ -73,7 +74,7 @@ class MassTransfer(Transaction):
             "senderPublicKey": self.sender_public_key,
             "fee": self.tx_fee,
             "timestamp": self.timestamp,
-            "attachment": base58.b58encode(crypto.str2bytes(self.attachment)),
+            "attachment": self.attachment.base58() if self.attachment else None,
             "transfers": self.transfers,
             "sponsor": self.sponsor,
             "sponsorKeyType": self.sponsor_key_type,
@@ -84,24 +85,7 @@ class MassTransfer(Transaction):
 
     @staticmethod
     def from_data(data):
-        tx = MassTransfer(transfers='')
-        tx.type = data['type']
-        tx.version = data['version']
-        tx.id = data['id'] if 'id' in data else ''
-        tx.sender = data['sender'] if 'sender' in data else ''
-        tx.sender_key_type = data['senderKeyType'] if 'senderKeyType' in data else 'ed25519'
-        tx.sender_public_key = data['senderPublicKey']
-        tx.fee = data['fee']
-        tx.timestamp = data['timestamp']
-        tx.proofs = data['proofs'] if 'proofs' in data else []
-        tx.attachment = data['attachment'] if 'attachment' in data else ''
-        tx.transfers = data['transfers']
-        tx.height = data['height'] if 'height' in data else ''
-
-        if "sponsor_public_key" in data:
-            tx.sponsor = data['sponsor']
-            tx.sponsor_public_key = data['sponsorPublicKey']
-            tx.sponsor_key_type = data['sponsorKeyType']
+        tx = MassTransfer(data['transfers'], Binary.frombase58(data.get('attachment', '')))
+        tx._init_from_data(data)
 
         return tx
-
